Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1287)

Unified Diff: components/safe_browsing_db/hit_report.h

Issue 1655113002: Add a new ThreatSource type to indicate SBHit is from client side detection. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: unit_tests and histogram Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/safe_browsing_db/hit_report.h
diff --git a/components/safe_browsing_db/hit_report.h b/components/safe_browsing_db/hit_report.h
index 5cb188677bb4651bed94fa856dc8f7a95e251057..ab90fcb25e2786e1c2d842375c3c2a9598655bf0 100644
--- a/components/safe_browsing_db/hit_report.h
+++ b/components/safe_browsing_db/hit_report.h
@@ -15,10 +15,11 @@ namespace safe_browsing {
// What service classified this threat as unsafe.
enum class ThreatSource {
UNKNOWN,
- DATA_SAVER, // From the Data Reduction service.
- LOCAL_PVER3, // From LocalSafeBrowingDatabaseManager, protocol v3
- LOCAL_PVER4, // From LocalSafeBrowingDatabaseManager, protocol v4
- REMOTE, // From RemoteSafeBrowingDatabaseManager
+ DATA_SAVER, // From the Data Reduction service.
+ LOCAL_PVER3, // From LocalSafeBrowingDatabaseManager, protocol v3
+ LOCAL_PVER4, // From LocalSafeBrowingDatabaseManager, protocol v4
+ REMOTE, // From RemoteSafeBrowingDatabaseManager
+ CLIENT_SIDE_DETECTION, // From ClientSideDetectionHost
};
// Data to report about the contents of a particular threat (malware, phishing,
« no previous file with comments | « chrome/browser/safe_browsing/safe_browsing_blocking_page.cc ('k') | tools/metrics/histograms/histograms.xml » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698